clear all
nfig=0;


%%%%------SETTING INPUT DATA------%%%%%%
if exist('nsample') == 0 nsample=1000; end
if exist('isampleplot') == 0 isampleplot=1; end

k1=1.2; k2=1.6; k3=1.8; k4=1.6;

for nlog=10:10
for snratio=5:1:5    
for ifunction=1:4
  
switch ifunction 
  case 1, fun='Bumps'; wtype='Daubechies'; filtersize=6;
  case 2, fun='Blocks'; wtype='Haar'; filtersize=[];
  case 3, fun='HeaviSine'; wtype='Symmlet'; filtersize=8;
  case 4, fun='Doppler'; wtype='Symmlet'; filtersize=8;
end

if ifunction==1
    k=k1;
elseif ifunction==2
    k=k2;
elseif ifunction==3
    k=k3;
elseif ifunction==4
    k=k4;
end    


%%%%%%%%%%%%%%%%INIZIALIZING%%%%%%%%%%%%%%%%%%%%%%%%%%%
n=2^nlog;  %number of observed data

ycumul=zeros(1,n);
ycumulvisuH=zeros(1,n);
ycumulhybrid=zeros(1,n);
ycumulabe=zeros(1,n);
ycumulnc=zeros(1,n);
ycumulblockJS_A=zeros(1,n);
ycumulCV=zeros(1,n);
ycumulbams=zeros(1,n);
ycumulFDR=zeros(1,n);

MSE=zeros(nsample,1);
MSEvisuH=zeros(nsample,1);
MSEhybrid=zeros(nsample,1);
MSEabe=zeros(nsample,1);
MSEnc=zeros(nsample,1);
MSECV=zeros(nsample,1);
MSEblockJS_A=zeros(nsample,1);
MSEbams=zeros(nsample,1);
MSEFDR=zeros(nsample,1);

qmf = MakeONFilter(wtype, filtersize); % making wavelet filters

step=1/n;
x=[0:step:1-step];
%
% GENERATING TRUE FUNCTION
%
ytrue=MakeSignalnewb(fun,n); 
sigma=std(ytrue);

randn('state', 0) %initializing random noise generator

caseplot=sprintf('n=%i snr=%i',n,snratio);
caseplot1=[ fun ];
caseplot=[ fun ' - ' caseplot ];

for isample=1:nsample
    
 %%%% GENERATING SAMPLE OF NOISE%%%% 
    noise=randn(1,n); 
    y = ytrue+sigma*noise/snratio;
    
    ysmooth=recMode2(y,qmf,k);
    ycumul = ycumul + ysmooth;  %needed for calculating the bias
    MSE(isample)=sum((ytrue-ysmooth).^2)/n;
            
            ybams=recmybams(y,qmf);
            MSEbams(isample)=sum((ytrue-ybams).^2)/n;
            ycumulbams = ycumulbams + ybams;
            
            yvisuH=recvisu(y,'H',qmf);
            MSEvisuH(isample)=sum((ytrue-yvisuH).^2)/n;
            ycumulvisuH = ycumulvisuH + yvisuH;
            
            yhybrid=rechybsure(y,qmf);
            MSEhybrid(isample)=sum((ytrue-yhybrid).^2)/n;
            ycumulhybrid = ycumulhybrid + yhybrid;

            yabe=recabe(y,qmf);        
            MSEabe(isample)=sum((ytrue-yabe).^2)/n;
            ycumulabe = ycumulabe + yabe;
            
            yCV=reccv(y,'H',qmf);
            MSECV(isample)=sum((ytrue-yCV).^2)/n;
            ycumulCV= ycumulCV + yCV;
      
            yFDR=recFDR(y,'H',qmf);
            MSEFDR(isample)=sum((ytrue-yFDR).^2)/n;
            ycumulFDR= ycumulFDR + yFDR;
            
            ync=recneighcoeff_s(y,qmf);
            MSEnc(isample)=sum((ytrue-ync).^2)/n;
            ycumulnc = ycumulnc + ync;  
            
            yblockJS_A = recblockJS('Augment',y,qmf);
            MSEblockJS_A(isample)=sum((ytrue-yblockJS_A).^2)/n;
            ycumulblockJS_A = ycumulblockJS_A + yblockJS_A;
            
            
       if isample==isampleplot 
            
            if ifunction==1
             nfig=nfig+1;   
             fignoise=nfig;   
             nfig=nfig+1;
             figfig=nfig;
            end
            
            figure(fignoise)
            subplot(2,2,ifunction)
            plot(x,y,'.')
            hold on 
            plot(x,ytrue,'r')
            title([caseplot1])

            figure(figfig)
            subplot(2,2,ifunction)
            plot(x,ysmooth)
            title([caseplot1])
            
            
            if ifunction==4
                figure(fignoise)
                gnamenoise=sprintf('./figure/n%isnr%iNoise_meth.eps',n,snratio);
                stringa=['print -depsc ' gnamenoise];
                eval(stringa);

                figure(figfig)
                gnameall=sprintf('./figure/n%isnr%iALL_meth.eps',n,snratio);
                stringa=['print -depsc ' gnameall];
                eval(stringa);
            end
 end 
end
ymean=ycumul/nsample;
clear ycumul;
AMSE=mean(MSE);
STDMSE=std(MSE);
BIAS2 = 1/n * sum((ytrue - ymean).^2);
VARIANCE = AMSE - BIAS2;

    ymeanbams=ycumulbams/nsample;
    clear ycumulbams;
    AMSEbams=mean(MSEbams);
    STDMSEbams=std(MSEbams);
    BIAS2bams = 1/n * sum((ytrue - ymeanbams).^2);
    VARIANCEbams = AMSEbams - BIAS2bams;

    ymeanvisuH=ycumulvisuH/nsample;
    clear ycumulvisuH;
    AMSEvisuH=mean(MSEvisuH);
    STDMSEvisuH=std(MSEvisuH);
    BIAS2visuH = 1/n * sum((ytrue - ymeanvisuH).^2);
    VARIANCEvisuH = AMSEvisuH - BIAS2visuH;    

    ymeanhybrid=ycumulhybrid/nsample;
    clear ycumulhybrid;
    AMSEhybrid=mean(MSEhybrid);
    STDMSEhybrid=std(MSEhybrid);
    BIAS2hybrid = 1/n * sum((ytrue - ymeanhybrid).^2);
    VARIANCEhybrid = AMSEhybrid - BIAS2hybrid; 

    ymeanabe=ycumulabe/nsample;
    clear ycumulabe;
    AMSEabe=mean(MSEabe);
    STDMSEabe=std(MSEabe);
    BIAS2abe = 1/n * sum((ytrue - ymeanabe).^2);
    VARIANCEabe = AMSEabe - BIAS2abe;

    
    ymeanCV=ycumulCV/nsample;
    clear ycumulCV;
    AMSECV=mean(MSECV);
    STDMSECV=std(MSECV);
    BIAS2CV = 1/n * sum((ytrue - ymeanCV).^2);
    VARIANCECV = AMSECV - BIAS2CV;
    
    
    ymeanFDR=ycumulFDR/nsample;
    clear ycumulFDR;
    AMSEFDR=mean(MSEFDR);
    STDMSEFDR=std(MSEFDR);
    BIAS2FDR = 1/n * sum((ytrue - ymeanFDR).^2);
    VARIANCEFDR = AMSEFDR - BIAS2FDR;
    
    ymeannc=ycumulnc/nsample;
    clear ycumulnc;
    AMSEnc=mean(MSEnc);
    STDMSEnc=std(MSEnc);
    BIAS2nc = 1/n * sum((ytrue - ymeannc).^2);
    VARIANCEnc = AMSEnc - BIAS2nc;
    
    ymeanblockJS_A=ycumulblockJS_A/nsample;
    clear ycumulblockJS_A;
    AMSEblockJS_A=mean(MSEblockJS_A);
    STDMSEblockJS_A=std(MSEblockJS_A);
    BIAS2blockJS_A = 1/n * sum((ytrue - ymeanblockJS_A).^2);
    VARIANCEblockJS_A = AMSEblockJS_A - BIAS2blockJS_A;
    
    
    MSE_methods=[MSE MSEbams MSEvisuH MSEhybrid MSEabe MSECV  MSEFDR MSEnc MSEblockJS_A];
   
    if ifunction==1
         nfig=nfig+1;
         figmse=nfig;
    end
    figure(figmse)
    subplot(2,2,ifunction)
    boxplot(MSE_methods)
    title([caseplot1])
    xlabel('')
    if ifunction==1 | ifunction==3 
     ylabel('AMSE')
    else
     ylabel('')
    end
    
    if ifunction==4
        gname1=sprintf('./figure/n%isnr%iAMSE_meth.eps',n,snratio);
        stringa=['print -deps ' gname1];
        eval(stringa);
    end
    
fprintf('\n\n Size of the sample: %i=2^%i\n',n,nlog);
fprintf(' Test function: %s\n',fun);
fprintf(' K: %f\n',k);
fprintf(' Signal to Noise ratio: %f\n',snratio);
fprintf(' Number of random samples: %i\n',nsample);
fprintf(' \n');
fprintf(' Wavelet type: %s\n',wtype);
fprintf(' Wavelet filter size: %i \n',filtersize);
fprintf(' \n');
fprintf('    METHOD     |    AMSE    |       STD     |      BIAS^2    | VARIANCE \n');
fprintf('---------------+------------+---------------+----------------+-------------\n');
fprintf(' LPM          |%d | %d | %d | %d | \n',AMSE,STDMSE,BIAS2,VARIANCE);
fprintf(' Bams         | %d| %d | %d | %d |  \n',AMSEbams,STDMSEbams,BIAS2bams,VARIANCEbams);
fprintf(' VISU   H     | %d| %d | %d | %d |  \n',AMSEvisuH,STDMSEvisuH,BIAS2visuH,VARIANCEvisuH);
fprintf(' Hybrid       | %d| %d | %d | %d |  \n',AMSEhybrid,STDMSEhybrid,BIAS2hybrid,VARIANCEhybrid);
fprintf(' ABE          | %d| %d | %d | %d |  \n',AMSEabe,STDMSEabe,BIAS2abe,VARIANCEabe);
fprintf(' CV           | %d| %d | %d | %d |  \n',AMSECV,STDMSECV,BIAS2CV,VARIANCECV);
fprintf(' FDR          | %d| %d | %d | %d |  \n',AMSEFDR,STDMSEFDR,BIAS2FDR,VARIANCEFDR);
fprintf(' NC           | %d| %d | %d | %d |  \n',AMSEnc,STDMSEnc,BIAS2nc,VARIANCEnc);
fprintf(' BJS          | %d| %d | %d | %d |  \n',AMSEblockJS_A,STDMSEblockJS_A,BIAS2blockJS_A,VARIANCEblockJS_A);

fname=sprintf('./output/t%in%is%i_meth.out',ifunction,n,snratio); %filename containing the output
    fid=fopen(fname,'w');
fprintf(fid,'\n\n Size of the sample: %i=2^%i\n',n,nlog);
fprintf(fid,' Test function: %s\n',fun);
fprintf(fid,' K: %f\n',k);
fprintf(fid,' Signal to Noise ratio: %f\n',snratio);
fprintf(fid,' Number of random samples: %i\n',nsample);
fprintf(fid,' \n');
fprintf(fid,' Wavelet type: %s\n',wtype);
fprintf(fid,' Wavelet filter size: %i \n',filtersize);
fprintf(' \n');
fprintf(fid,'    METHOD    |    AMSE     |       STD     |      BIAS^2    | VARIANCE \n');
fprintf(fid,'--------------+-------------+---------------+----------------+-------------\n');
fprintf(fid,' LPM          |%d | %d | %d | %d | \n',AMSE,STDMSE,BIAS2,VARIANCE);
fprintf(fid,' Bams         | %d| %d | %d | %d |  \n',AMSEbams,STDMSEbams,BIAS2bams,VARIANCEbams);
fprintf(fid,' VISU  H      | %d| %d | %d | %d | \n',AMSEvisuH,STDMSEvisuH,BIAS2visuH,VARIANCEvisuH);
fprintf(fid,' Hybrid       | %d| %d | %d | %d |  \n',AMSEhybrid,STDMSEhybrid,BIAS2hybrid,VARIANCEhybrid);
fprintf(fid,' ABE          | %d| %d | %d | %d |  \n',AMSEabe,STDMSEabe,BIAS2abe,VARIANCEabe);
fprintf(fid,' CV           | %d| %d | %d | %d |  \n',AMSECV,STDMSECV,BIAS2CV,VARIANCECV);
fprintf(fid,' FDR          | %d| %d | %d | %d |  \n',AMSEFDR,STDMSEFDR,BIAS2FDR,VARIANCEFDR);
fprintf(fid,' NC           | %d| %d | %d | %d |  \n',AMSEnc,STDMSEnc,BIAS2nc,VARIANCEnc);
fprintf(fid,' BJS          | %d| %d | %d | %d |  \n',AMSEblockJS_A,STDMSEblockJS_A,BIAS2blockJS_A,VARIANCEblockJS_A);
fclose(fid);

end % ifunction
end %end SNRATIO
end %nlog