function w = neighcoeff(wcoef,lambda,sigma)

% neighblock -- Group the empirical wavelet coefficients into disjoint blocks of length L=3. 
% Extract the wavelet coefficient using the NeighBlock procedure of Cai and Silverman
% Usage
%   w = neighcoeff(wcoef,sigma)
% Inputs
%   wcoef	Empirical wavelet coefficients at a given resolution level
%   sigma	Level of noise
% Outputs
%   w		Denoised wavelet coefficients
% References	``Incorporating Information on Neighboring Coefficients into Wavelet Estimation'' 
% by T. Tony Cai and B.W. Silverman.

   L0 = 1;
	L1 = 1;
   L = L0 + 2*L1;
  	thresh = lambda*L*sigma^2;
	m = length(wcoef);
	 
	yy = [wcoef((m-L1+1):m) wcoef wcoef(1:L1)];
	SS = 1:m;
	for b = 1:m,
		SS(b) = sum(yy(((b-1)*L0+1):((b-1)*L0+L)).^2);
	end
	factor = max(0,1-thresh./SS);
	for b = 1:m,
		wcoef(((b-1)*L0+1):(b*L0)) = wcoef(((b-1)*L0+1):(b*L0)) * factor(b);
	end
	
	w = wcoef;
	
