function f=recABE(y,qmf)
%
% recABE   :  Smoothing using ABE thresholding rule
%
% Usage
%              f = recABE(y,qmf)
% Inputs
%   y   	      1-d Noisy signal, length(signal)= 2^J
%   qmf 	      Quadrature Mirror Filter for Wavelet Transform.
%		        
% Outputs
%   f          Estimate, obtained by applying ABE thresholding on the 
%              wavelet coefficients.
%
% References
%             Figueiredo M.A.T. & Nowak R.D. (2001) Wavelet-based Image estimation:
%                            an empirical Bayes Approach Using Jeffreys'Non informative prior
%                      IEEE Transaction on Image Processing, vol 10, n.9
%
% Last modified 16 March 2002 
%
%initialization 

  n=length(y);
  nlog=log2(n);
  minlev=floor(log2(log(n))) + 1;  % Coarsest wavelet decomposition

  wy = FWT_PO(y, minlev, qmf);  %computing the wavelet transform

  dum=wy(dyad(nlog-1));
    
    sigmadum=median(abs(dum))/0.6745; % estimate of the standard deviation of the noise using MAD
    clear dum;
    
     wyabe=zeros(size(wy));
     dummy2=wy(2^minlev+1:n);
     
    dummy1=max(dummy2.^2-3*sigmadum^2,0);
    
    pos=find(abs(dummy1)>0);
    
    dummy1(pos)=dummy1(pos)./dummy2(pos);
    
    wy(2^minlev+1:n)=dummy1;
  
    f=IWT_PO(wy, minlev, qmf);
    
% Copyright (c) 2002
%
% Claudia Angelini
% Istituto per le Applicazioni del Calcolo 'M. Picone' - Napoli Section
% Consiglio Nazionale delle Ricerche
% Via P. Castellino 111
% 80131 Napoli
% Italy
%
% mailto: angelini@iam.na.cnr.it
%
% and
%
% Theofanis Sapatinas
% Department of Mathematics and Statistics
% University of Cyprus
% P.O. Box 20537  
% CY 1678 Nicosia
% Cyprus.
%
% mailto: T.Sapatinas@ucy.ac.cy 
