function f=recMode2(y,qmf,k);
%
% recGamma   :  Smoothing using Gamma-minimax thresholding rule
%
% Usage
%              f = recGamma(y,qmf,gamma)
% Inputs
%   y   	      1-d Noisy signal, length(signal)= 2^J
%   qmf 	      Quadrature Mirror Filter for Wavelet Transform.
%  gamma          power for the probability of a coefficient of being 0 
%                 eps0(lev)=1-1/(lev-minlev+1)^gamma;   SUGGESTED VALUE OF EPS_0 in BAMS

%		        
% Outputs
%   f          Estimate, obtained by applying Gamma-minimax thresholding on the rule   
%              wavelet coefficients.
%
%
%
%initialization 

if nargin<3 
    k=3/4;
end

  n=length(y);
  nlog=log2(n);

    minlev=floor(log2(log(n))) + 1;  % Default Coarsest wavelet decomposition
  
  wy = FWT_PO(y, minlev, qmf); %computing the wavelet transform
    
  dum=wy(dyad(nlog-1));
  const = 1;
  sigmadum= const * median(abs(dum - median(dum)))/0.6745; % estimate of the standard deviation of the noise using MAD
lamb=2*sigmadum*sqrt(2*k-1);
ind=find(abs(wy)>lamb);
wysmooth=zeros(size(wy));
ddd=wy(ind);

c=4*sigmadum^2*(2*k-1);
ddd=(ddd + sign(ddd).* sqrt(ddd.^2 -c ))*0.5;
wysmooth(ind)=ddd;
% wyy = wy .* (1 - (sigmadum^2 * (2 * k -1))./(2*wy.^2));
% wysmooth = wyy .* (abs(wy) > 2 * sigmadum * sqrt(2 * k - 1));

 %   wysmooth(1:2^minlev)=wy(1:2^minlev); %Coarse coefficient will be untouched
    
    f = IWT_PO(wysmooth, minlev, qmf);