function f=recMode2_ig(y,qmf,k,a);
%
% recGamma   :  Smoothing using Gamma-minimax thresholding rule
%
% Usage
%              f = recGamma(y,qmf,gamma)
% Inputs
%   y   	      1-d Noisy signal, length(signal)= 2^J
%   qmf 	      Quadrature Mirror Filter for Wavelet Transform.
%  gamma          power for the probability of a coefficient of being 0 
%                 eps0(lev)=1-1/(lev-minlev+1)^gamma;   SUGGESTED VALUE OF EPS_0 in BAMS

%		        
% Outputs
%   f          Estimate, obtained by applying Gamma-minimax thresholding on the rule   
%              wavelet coefficients.
%
%
%

%initialization 

  n=length(y);
  nlog=log2(n);

  minlev=floor(log2(log(n))) + 1;  % Default Coarsest wavelet decomposition
  
  wy = FWT_PO(y, minlev, qmf); %computing the wavelet transform
    
  dum=wy(dyad(nlog-1));
  sigmadum=  median(abs(dum - median(dum)))/0.6745; % estimate of the standard deviation of the noise using MAD

  b = sigmadum^2 * (a - 1);

 lambda =  4/(2 * a + 1) * sqrt( (2 * k -1 ) * (k + a) * b );

 indices = find( abs(wy) > lambda );



wysmooth = zeros(size(wy));
wysmooth(indices) = ( (2*a+4*k-1).*wy(indices) + sign(wy(indices)).*sqrt( (2*a+1)^2 * wy(indices).^2 + 16*(1-2*k)*(k+a)*b ) )./ (4*(k+a)) ;


    
 f = IWT_PO(wysmooth, minlev, qmf);
   