function f = recneighcoeff_s(signal,h)

%recneighblock_s -- Extract wavelet coefficients from data using the NeighBlock procedure
% Usage
%   f=recneighcoeff_s(signal,h)
% Inputs
%   signal	1-d Noisy signal, length(signal)= 2^J
%   h 		Quadrature Mirror Filter for Wavelet Transform
%		Optional, Default = Symmlet 8
% Outputs
%   out		Estimate, obtained by applying thresholding on wavelet coefficients
% References	``Incorporating Information on Neighboring Coefficients into Wavelet Estimation'' by T. Tony Cai and B.W. Silverman.

%initialisations
n=length(signal);
lev=floor(log2(log(n)))+1;

if nargin < 2,
	h = MakeONFilter('Symmlet',8);
end

%h=MakeONFilter('Symmlet',8);
wcoef=FWT_PO(signal,lev,h);

%extract wavelet coeff's by level
J=log2(n);
wthresh=wcoef;

%estimate sigma
highestlev=wcoef(2^(J-1)+1:2^J);
sigma=median(abs(highestlev))/0.6745;

% define lambda
lambda = 2*log(n)/3; 

for j=lev:J-1
 wthresh(2^j+1:2^(j+1))=neighcoeff(wcoef(2^j+1:2^(j+1)),lambda,sigma);
end  
reconstruct=IWT_PO(wthresh,lev,h);

f=reconstruct;
